==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tutti gli Argomenti");
define("_NOCOMMENTS","Nessun Commento");
define("_UCOMMENT","Commento");
define("_REVIEWS","Recensioni");
define("_SEARCHUSERS","Cerca nel Database Utenti");
define("_SEARCHSECTIONS","Cerca nelle Sezioni Speciali");
define("_SEARCHREVIEWS","Cerca nelle Recensioni");
define("_SEARCHIN","Cerca in");
define("_ARTICLES","Articoli");
define("_ALLAUTHORS","Tutti gli Autori");
define("_ALL","Tutto");
define("_WEEK","settimana");
define("_WEEKS","settimane");
define("_MONTH","mese");
define("_MONTHS","mesi");
define("_SEARCHON","Cerca su:");
define("_SSTORIES","Articoli");
define("_SSECTIONS","Sezioni");
define("_SUSERS","Utenti");
define("_NOMATCHES","Nessun Risultato per la tua ricerca");
define("_PREVMATCHES","precedenti");
define("_NEXTMATCHES","successivi");
define("_INSECTION","Articoli nella Sezione");
define("_NONAME","Nessun nome inserito");
define("_SCOMMENTS","Commenti");
define("_SEARCHRESULTS","Risultati Ricerca");
define("_CONTRIBUTEDBY","Contributo di");
define("_UCOMMENTS","Commenti");
define("_MATCHTITLE","Sul Titolo");
define("_MATCHTEXT","Sul testo Articolo");
define("_MATCHBOTH","Sul Titolo e sul testo Articolo");
define("_SREPLY","Replica");
define("_SREPLIES","Repliche");
define("_ATTACHART","Allegato all'Articolo");
define("_PAGES","Pagine");
define("_REVIEWSCORE","Voto per questa Recensione");
define("_PAGE","Pagina");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tutti gli Argomenti");
define("_NOCOMMENTS","Nessun Commento");
define("_UCOMMENT","Commento");
define("_REVIEWS","Recensioni");
define("_SEARCHUSERS","Cerca nel Database Utenti");
define("_SEARCHSECTIONS","Cerca nelle Sezioni Speciali");
define("_SEARCHREVIEWS","Cerca nelle Recensioni");
define("_SEARCHIN","Cerca in");
define("_ARTICLES","Articoli");
define("_ALLAUTHORS","Tutti gli Autori");
define("_ALL","Tutto");
define("_WEEK","settimana");
define("_WEEKS","settimane");
define("_MONTH","mese");
define("_MONTHS","mesi");
define("_SEARCHON","Cerca su:");
define("_SSTORIES","Articoli");
define("_SSECTIONS","Sezioni");
define("_SUSERS","Utenti");
define("_NOMATCHES","Nessun Risultato per la tua ricerca");
define("_PREVMATCHES","precedenti");
define("_NEXTMATCHES","successivi");
define("_INSECTION","Articoli nella Sezione");
define("_NONAME","Nessun nome inserito");
define("_SCOMMENTS","Commenti");
define("_SEARCHRESULTS","Risultati Ricerca");
define("_CONTRIBUTEDBY","Contributo di");
define("_UCOMMENTS","Commenti");
define("_MATCHTITLE","Sul Titolo");
define("_MATCHTEXT","Sul testo Articolo");
define("_MATCHBOTH","Sul Titolo e sul testo Articolo");
define("_SREPLY","Replica");
define("_SREPLIES","Repliche");
define("_ATTACHART","Allegato all'Articolo");
define("_PAGES","Pagine");
define("_REVIEWSCORE","Voto per questa Recensione");
define("_PAGE","Pagina");

?>
